@@ -1,18 +1,22 @@
 import time
-from typing_extensions import Literal
+
 from rich import box
+from rich.console import Console, Group
 from rich.panel import Panel
-from rich.table import Table
 from rich.progress import track
-from rich.console import RenderGroup, Console
+from rich.table import Table
+from typing_extensions import Literal
+
+from pyintelowl.exceptions import IntelOwlClientException
+
 from ..cli._utils import (
+    get_json_syntax,
     get_status_text,
     get_success_text,
     get_tags_str,
-    get_json_syntax,
 )
-from pyintelowl.exceptions import IntelOwlClientException
-from ..cli.domain_checkers import Checkers, console as checkers_console
+from ..cli.domain_checkers import Checkers
+from ..cli.domain_checkers import console as checkers_console
 
 
 def _display_single_job(
@@ -70,9 +74,11 @@ def _render_job_attributes(data):
         else data["file_mimetype"]
     )
     status: str = get_status_text(data["status"], as_text=False)
-    r = RenderGroup(
+    console = Console()
+    console.print(data)
+    r = Group(
         f"{style}Job ID:[/] {str(data['id'])}",
-        f"{style}User:[/] {data['source']}",
+        f"{style}User:[/] {data['user']['username']}",
         f"{style}MD5:[/] {data['md5']}",
         f"{style}Name:[/] {name}",
         f"{style}Classification:[/] {clsfn}",
@@ -110,14 +116,14 @@ def _display_all_jobs(logger, rows):
                 if el["observable_classification"]
                 else el["file_mimetype"],
                 ", ".join([t["label"] for t in el["tags"]]),
-                el["no_of_analyzers_executed"],
-                el["no_of_connectors_executed"],
+                ", ".join(el["analyzers_to_execute"]),
+                ", ".join(el["connectors_to_execute"]),
                 str(el["process_time"]),
                 get_status_text(el["status"]),
             )
         console.print(table, justify="center")
     except Exception as e:
-        logger.fatal(e)
+        logger.fatal(e, exc_info=True)
 
 
 def _result_filter_and_tabular_print(result, observable: str, obs_clsfn: str):
