@@ -1,7 +1,8 @@
 import click
 
 from pyintelowl.exceptions import IntelOwlClientException
-from ..cli._utils import add_options, ClickContext, get_json_data
+
+from ..cli._utils import ClickContext, add_options, get_json_data
 
 __analyse_options = [
     click.option(
@@ -29,7 +30,7 @@ __analyse_options = [
         "--tags-list",
         type=str,
         default="",
-        help="Comma separated list of tag indices for respective job.",
+        help="Comma separated list of tag labels to assign (creates non-existing tags)",
     ),
     click.option(
         "-t",
@@ -50,6 +51,14 @@ __analyse_options = [
     3. 'force_new': force new analysis
     """,
     ),
+    click.option(
+        "-m",
+        "--check-minutes-ago",
+        type=int,
+        default=None,
+        help="Number of minutes ago to check for"
+        " a previous analysis. Default infinity.",
+    ),
     click.option(
         "-r",
         "--runtime-config",
@@ -57,6 +66,7 @@ __analyse_options = [
         type=click.Path(exists=True, resolve_path=True),
     ),
     click.option(
+        "-p",
         "--poll",
         "should_poll",
         is_flag=True,
@@ -78,21 +88,19 @@ def analyse():
 @click.pass_context
 def observable(
     ctx: ClickContext,
-    value,
+    value: str,
     analyzers_list: str,
     connectors_list: str,
     tags_list: str,
-    tlp,
+    tlp: str,
     check,
+    check_minutes_ago: int,
     runtime_config,
     should_poll: bool,
 ):
     analyzers_list = analyzers_list.split(",") if len(analyzers_list) else []
     connectors_list = connectors_list.split(",") if len(connectors_list) else []
-    if tags_list:
-        tags_list = list(map(int, tags_list.split(",")))
-    else:
-        tags_list = []
+    tags_labels = tags_list.split(",") if len(tags_list) else []
     if runtime_config:
         runtime_config = get_json_data(runtime_config)
     else:
@@ -106,8 +114,9 @@ def observable(
             analyzers_list,
             connectors_list,
             runtime_config,
-            tags_list,
+            tags_labels,
             should_poll,
+            check_minutes_ago,
         )
     except IntelOwlClientException as e:
         ctx.obj.logger.fatal(str(e))
@@ -123,17 +132,15 @@ def file(
     analyzers_list: str,
     connectors_list: str,
     tags_list: str,
-    tlp,
+    tlp: str,
     check,
+    check_minutes_ago: int,
     runtime_config,
     should_poll: bool,
 ):
     analyzers_list = analyzers_list.split(",") if len(analyzers_list) else []
     connectors_list = connectors_list.split(",") if len(connectors_list) else []
-    if tags_list:
-        tags_list = list(map(int, tags_list.split(",")))
-    else:
-        tags_list = []
+    tags_labels = tags_list.split(",") if len(tags_list) else []
     if runtime_config:
         runtime_config = get_json_data(runtime_config)
     else:
@@ -147,8 +154,9 @@ def file(
             analyzers_list,
             connectors_list,
             runtime_config,
-            tags_list,
+            tags_labels,
             should_poll,
+            check_minutes_ago,
         )
     except IntelOwlClientException as e:
         ctx.obj.logger.fatal(str(e))
