@@ -1,23 +1,17 @@
+import hashlib
 import ipaddress
+import json
 import logging
 import pathlib
-import json
 import re
+from typing import Any, AnyStr, Callable, Dict, List, Optional, Union
+
 import requests
-import hashlib
-from typing import (
-    List,
-    Dict,
-    Any,
-    Optional,
-    Union,
-    AnyStr,
-    Callable,
-)
 from typing_extensions import Literal
 
-from .exceptions import IntelOwlClientException
+from pyintelowl.version import __version__
 
+from .exceptions import IntelOwlClientException
 
 TLPType = Literal["WHITE", "GREEN", "AMBER", "RED"]
 
@@ -54,7 +48,7 @@ class IntelOwl:
             session.headers.update(
                 {
                     "Authorization": f"Token {self.token}",
-                    "User-Agent": "IntelOwlClient/3.1.3",
+                    "User-Agent": f"PyIntelOwl/{__version__}",
                 }
             )
             self._session = session
@@ -98,6 +92,7 @@ class IntelOwl:
         md5: str,
         analyzers: List[str] = None,
         check_reported_analysis_too: bool = False,
+        minutes_ago: int = None,
     ) -> Dict:
         """Search for already available analysis.\n
         Endpoint: ``/api/ask_analysis_availability``
@@ -109,6 +104,9 @@ class IntelOwl:
             Defaults to `None` meaning automatically select all configured analyzers.
             check_reported_analysis_too (bool, optional):
             Check against all existing jobs. Defaults to ``False``.
+            minutes_ago (int, optional):
+            number of minutes to check back for analysis.
+            Default is None so the check does not have any time limits.
 
         Raises:
             IntelOwlClientException: on client/HTTP error
@@ -121,6 +119,8 @@ class IntelOwl:
         data = {"md5": md5, "analyzers": analyzers}
         if not check_reported_analysis_too:
             data["running_only"] = True
+        if minutes_ago:
+            data["minutes_ago"] = int(minutes_ago)
         url = self.instance + "/api/ask_analysis_availability"
         response = self.__make_request("POST", url=url, data=data)
         answer = response.json()
@@ -142,11 +142,11 @@ class IntelOwl:
         self,
         filename: str,
         binary: bytes,
-        tlp: TLPType = "WHITE",
+        tlp: TLPType = None,
         analyzers_requested: List[str] = None,
         connectors_requested: List[str] = None,
         runtime_configuration: Dict = None,
-        tags: List[int] = None,
+        tags_labels: List[str] = None,
     ) -> Dict:
         """Send analysis request for a file.\n
         Endpoint: ``/api/analyze_file``
@@ -168,8 +168,8 @@ class IntelOwl:
                 (options: ``WHITE, GREEN, AMBER, RED``). Defaults to ``WHITE``.
             runtime_configuration (Dict, optional):
                 Overwrite configuration for analyzers. Defaults to ``{}``.
-            tags (List[int], optional):
-                List of tags associated with this job
+            tags_labels (List[str], optional):
+                List of tag labels to assign (creates non-existing tags)
 
         Raises:
             IntelOwlClientException: on client/HTTP error
@@ -178,22 +178,22 @@ class IntelOwl:
             Dict: JSON body
         """
         try:
+            if not tlp:
+                tlp = "WHITE"
             if not analyzers_requested:
                 analyzers_requested = []
             if not connectors_requested:
                 connectors_requested = []
-            if not tags:
-                tags = []
+            if not tags_labels:
+                tags_labels = []
             if not runtime_configuration:
                 runtime_configuration = {}
             data = {
-                "is_sample": True,
-                "md5": self.get_md5(binary, type_="binary"),
                 "file_name": filename,
                 "analyzers_requested": analyzers_requested,
                 "connectors_requested": connectors_requested,
                 "tlp": tlp,
-                "tags_id": tags,
+                "tags_labels": tags_labels,
             }
             if runtime_configuration:
                 data["runtime_configuration"] = json.dumps(runtime_configuration)
@@ -206,11 +206,12 @@ class IntelOwl:
     def send_observable_analysis_request(
         self,
         observable_name: str,
-        tlp: TLPType = "WHITE",
+        tlp: TLPType = None,
         analyzers_requested: List[str] = None,
         connectors_requested: List[str] = None,
         runtime_configuration: Dict = None,
-        tags: List[int] = None,
+        tags_labels: List[str] = None,
+        observable_classification: str = None,
     ) -> Dict:
         """Send analysis request for an observable.\n
         Endpoint: ``/api/analyze_observable``
@@ -229,38 +230,55 @@ class IntelOwl:
                 (options: ``WHITE, GREEN, AMBER, RED``). Defaults to ``WHITE``.
             runtime_configuration (Dict, optional):
                 Overwrite configuration for analyzers. Defaults to ``{}``.
-            tags (List[int], optional):
-                List of tags associated with this job
+            tags_labels (List[str], optional):
+                List of tag labels to assign (creates non-existing tags)
+            observable_classification (str):
+                Observable classification, Default to None.
+                By default launch analysis with an automatic classification.
+                (options: ``url, domain, hash, ip, generic``)
 
         Raises:
             IntelOwlClientException: on client/HTTP error
+            IntelOwlClientException: on wrong observable_classification
 
         Returns:
             Dict: JSON body
         """
         try:
+            if not tlp:
+                tlp = "WHITE"
             if not analyzers_requested:
                 analyzers_requested = []
             if not connectors_requested:
                 connectors_requested = []
-            if not tags:
-                tags = []
+            if not tags_labels:
+                tags_labels = []
             if not runtime_configuration:
                 runtime_configuration = {}
-            data = {
-                "is_sample": False,
-                "md5": self.get_md5(observable_name, type_="observable"),
-                "observable_name": observable_name,
-                "observable_classification": self._get_observable_classification(
+            if not observable_classification:
+                observable_classification = self._get_observable_classification(
                     observable_name
-                ),
+                )
+            elif observable_classification not in [
+                "generic",
+                "hash",
+                "ip",
+                "domain",
+                "url",
+            ]:
+                raise IntelOwlClientException(
+                    "Observable classification only handle"
+                    " 'generic', 'hash', 'ip', 'domain' and 'url' "
+                )
+            data = {
+                "observable_name": observable_name,
+                "observable_classification": observable_classification,
                 "analyzers_requested": analyzers_requested,
                 "connectors_requested": connectors_requested,
                 "tlp": tlp,
-                "tags_id": tags,
+                "tags_labels": tags_labels,
+                "runtime_configuration": runtime_configuration,
             }
-            if runtime_configuration:
-                data["runtime_configuration"] = json.dumps(runtime_configuration)
             answer = self.__send_analysis_request(data=data, files=None)
         except Exception as e:
             raise IntelOwlClientException(e)
@@ -315,11 +333,13 @@ class IntelOwl:
         response = None
         if files is None:
             url = self.instance + "/api/analyze_observable"
+            args = {"json": data}
         else:
             url = self.instance + "/api/analyze_file"
+            args = {"data": data, "files": files}
 
         try:
-            response = self.session.post(url, data=data, files=files)
+            response = self.session.post(url, **args)
             self.logger.debug(
                 msg={
                     "url": response.url,
@@ -417,7 +437,7 @@ class IntelOwl:
             IntelOwlClientException: on client/HTTP error
 
         Returns:
-            List[Dict[str, Any]]: List of jobs
+            Dict: Dict with 3 keys: "count", "total_pages", "results"
         """
         url = self.instance + "/api/jobs"
         response = self.__make_request("GET", url=url)
@@ -443,7 +463,7 @@ class IntelOwl:
 
     def get_job_by_id(self, job_id: Union[int, str]) -> Dict[str, Any]:
         """Fetch job info by ID.
-        Endpoint: ``/api/job/{job_id}``
+        Endpoint: ``/api/jobs/{job_id}``
 
         Args:
             job_id (Union[int, str]): Job ID
@@ -499,8 +519,9 @@ class IntelOwl:
         analyzers_list: List[str] = None,
         connectors_list: List[str] = None,
         runtime_configuration: Dict = None,
-        tags_list: List[int] = None,
+        tags_labels: List[str] = None,
         should_poll: bool = False,
+        minutes_ago: int = None,
     ) -> None:
         """
         For internal use by the pyintelowl CLI.
@@ -511,20 +532,25 @@ class IntelOwl:
             connectors_list = []
         if not runtime_configuration:
             runtime_configuration = {}
-        if not tags_list:
-            tags_list = []
+        if not tags_labels:
+            tags_labels = []
         self.logger.info(
             f"""Requesting analysis..
             {type_}: [blue]{obj}[/]
             analyzers: [i green]{analyzers_list if analyzers_list else 'all'}[/]
             connectors: [i green]{connectors_list if connectors_list else 'all'}[/]
+            tags: [i green]{tags_labels}[/]
             """
         )
         # 1st step: ask analysis availability
         if check != "force-new":
             md5 = self.get_md5(obj, type_=type_)
+
             resp = self.ask_analysis_availability(
-                md5, analyzers_list, True if check == "reported" else False
+                md5,
+                analyzers_list,
+                True if check == "reported" else False,
+                minutes_ago,
             )
             status, job_id = resp.get("status", None), resp.get("job_id", None)
             if status != "not_available":
@@ -545,7 +571,7 @@ class IntelOwl:
                 analyzers_requested=analyzers_list,
                 connectors_requested=connectors_list,
                 runtime_configuration=runtime_configuration,
-                tags=tags_list,
+                tags_labels=tags_labels,
             )
         else:
             path = pathlib.Path(obj)
@@ -556,7 +582,7 @@ class IntelOwl:
                 analyzers_requested=analyzers_list,
                 connectors_requested=connectors_list,
                 runtime_configuration=runtime_configuration,
-                tags=tags_list,
+                tags_labels=tags_labels,
             )
         # 3rd step: poll for result
         if should_poll:
@@ -594,7 +620,7 @@ class IntelOwl:
             ipaddress.ip_address(value)
         except ValueError:
             if re.match(
-                r"^(?:ht|f)tps?://[a-z\d-]{1,63}(?:\.[a-z\d-]{1,63})+"
+                r"^(?:htt|ft|tc)ps?://[a-z\d-]{1,63}(?:\.[a-z\d-]{1,63})+"
                 r"(?:/[a-z\d-]{1,63})*(?:\.\w+)?",
                 value,
             ):
@@ -711,7 +737,7 @@ class IntelOwl:
         response = None
         url = (
             self.instance
-            + f"/api/job/{job_id}/{plugin_type}/{plugin_name}/{plugin_action}"
+            + f"/api/jobs/{job_id}/{plugin_type}/{plugin_name}/{plugin_action}"
         )
         response = self.__make_request("PATCH", url=url)
         success = response.status_code == 204
@@ -720,7 +746,7 @@ class IntelOwl:
     def kill_analyzer(self, job_id: int, analyzer_name: str) -> bool:
         """Send kill running/pending analyzer request.\n
         Method: PATCH
-        Endpoint: ``/api/job/{job_id}/analyzer/{analyzer_name}/kill``
+        Endpoint: ``/api/jobs/{job_id}/analyzer/{analyzer_name}/kill``
 
         Args:
             job_id (int):
@@ -746,7 +772,7 @@ class IntelOwl:
     def kill_connector(self, job_id: int, connector_name: str) -> bool:
         """Send kill running/pending connector request.\n
         Method: PATCH
-        Endpoint: ``/api/job/{job_id}/connector/{connector_name}/kill``
+        Endpoint: ``/api/jobs/{job_id}/connector/{connector_name}/kill``
 
         Args:
             job_id (int):
@@ -772,7 +798,7 @@ class IntelOwl:
     def retry_analyzer(self, job_id: int, analyzer_name: str) -> bool:
         """Send retry failed/killed analyzer request.\n
         Method: PATCH
-        Endpoint: ``/api/job/{job_id}/analyzer/{analyzer_name}/retry``
+        Endpoint: ``/api/jobs/{job_id}/analyzer/{analyzer_name}/retry``
 
         Args:
             job_id (int):
@@ -798,7 +824,7 @@ class IntelOwl:
     def retry_connector(self, job_id: int, connector_name: str) -> bool:
         """Send retry failed/killed connector request.\n
         Method: PATCH
-        Endpoint: ``/api/job/{job_id}/connector/{connector_name}/retry``
+        Endpoint: ``/api/jobs/{job_id}/connector/{connector_name}/retry``
 
         Args:
             job_id (int):
@@ -834,9 +860,7 @@ class IntelOwl:
             IntelOwlClientException: on client/HTTP error
 
         Returns:
-            Dict: {
-                `status`: `True/False/None`
-            }
+            Bool: success or not
         """
 
         url = self.instance + f"/api/analyzer/{analyzer_name}/healthcheck"
@@ -856,9 +880,7 @@ class IntelOwl:
             IntelOwlClientException: on client/HTTP error
 
         Returns:
-            Dict: {
-                `status`: `True/False/None`
-            }
+            Bool: success or not
         """
         url = self.instance + f"/api/connector/{connector_name}/healthcheck"
         response = self.__make_request("GET", url=url)
