@@ -1,9 +1,4 @@
-from .utils import (
-    MockResponse,
-    get_file_data,
-    ROOT_DIR,
-    TEST_FILE,
-)
+from tests.utils import ROOT_DIR, TEST_FILE, MockResponse, get_file_data
 
 
 def mocked_raise_exception(*args, **kwargs):
@@ -26,7 +21,7 @@ def mocked_analyzer_config(*args, **kwargs):
             }
         },
         200,
-        "api/get_analyzer_configs",
+        "/api/get_analyzer_configs",
     )
 
 
@@ -43,7 +38,7 @@ def mocked_connector_config(*args, **kwargs):
             }
         },
         200,
-        "api/get_connector_configs",
+        "/api/get_connector_configs",
     )
 
 
@@ -55,7 +50,7 @@ def mocked_ask_analysis_success(*args, **kwargs):
             "analyzers_to_execute": ["test_1", "test_2"],
         },
         200,
-        "api/ask_analysis_availability",
+        "/api/ask_analysis_availability",
     )
 
 
@@ -65,7 +60,7 @@ def mocked_ask_analysis_no_status(*args, **kwargs):
             "job_id": 1,
         },
         200,
-        "api/ask_analysis_availability",
+        "/api/ask_analysis_availability",
     )
 
 
@@ -78,7 +73,7 @@ def mocked_send_analysis_success(*args, **kwargs):
             "analyzers_running": ["test_1", "test_2"],
         },
         200,
-        "api/analyze_observable",
+        "/api/analyze_observable",
     )
 
 
@@ -88,7 +83,7 @@ def mocked_ask_analysis_no_job_id(*args, **kwargs):
             "status": "running",
         },
         200,
-        "api/ask_analysis_availability",
+        "/api/ask_analysis_availability",
     )
 
 
@@ -112,13 +107,13 @@ def mocked_get_job_by_id(*args, **kwargs):
             ],
         },
         200,
-        "/api/job/1",
+        "/api/jobs/1",
     )
 
 
 def mocked_get_all_jobs(*args, **kwargs):
     return MockResponse(
-        [],
+        {"count": 1, "total_pages": 1, "results": []},
         200,
         "/api/jobs",
     )
@@ -144,7 +139,7 @@ def mocked_kill_analyzer(*args, **kwargs):
     return MockResponse(
         True,
         204,
-        "/api/job/1/analyzer/MISP/kill",
+        "/api/jobs/1/analyzer/MISP/kill",
     )
 
 
@@ -152,7 +147,7 @@ def mocked_kill_connector(*args, **kwargs):
     return MockResponse(
         True,
         204,
-        "/api/job/1/connector/MISP/kill",
+        "/api/jobs/1/connector/MISP/kill",
     )
 
 
@@ -160,7 +155,7 @@ def mocked_retry_analyzer(*args, **kwargs):
     return MockResponse(
         True,
         204,
-        "/api/job/1/analyzer/MISP/retry",
+        "/api/jobs/1/analyzer/MISP/retry",
     )
 
 
@@ -168,7 +163,7 @@ def mocked_retry_connector(*args, **kwargs):
     return MockResponse(
         True,
         204,
-        "/api/job/1/connector/MISP/retry",
+        "/api/jobs/1/connector/MISP/retry",
     )
 
 
